@@ -129,7 +129,7 @@ AcquireImageDialog::AcquireImageDialog( KIPI::Interface* interface, TQWidget *pa
     m_helpButton = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQT_SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQ_SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 }
 
@@ -226,7 +226,7 @@ void AcquireImageDialog::setupImageOptions(void)
     //---------------------------------------------
 
     TQGroupBox * groupBox2 = new TQGroupBox( i18n("Saving Options"), page_setupImageOptions );
-    groupBox2->setColumnLayout(0, Qt::Vertical );
+    groupBox2->setColumnLayout(0, TQt::Vertical );
     groupBox2->layout()->setSpacing( 6 );
     groupBox2->layout()->setMargin( 11 );
     TQWhatsThis::add( groupBox2, i18n("<p>The saving options of the target image.") );
@@ -292,8 +292,8 @@ void AcquireImageDialog::setupImageOptions(void)
 
     //---------------------------------------------
 
-    connect(m_imagesFormat, TQT_SIGNAL(activated(const TQString &)),
-            this, TQT_SLOT(slotImageFormatChanged(const TQString &)));
+    connect(m_imagesFormat, TQ_SIGNAL(activated(const TQString &)),
+            this, TQ_SLOT(slotImageFormatChanged(const TQString &)));
 }
 
 void AcquireImageDialog::setupAlbumsList(void)
@@ -326,7 +326,7 @@ void AcquireImageDialog::setupAlbumsList(void)
     //---------------------------------------------
 
     TQGroupBox * groupBox2 = new TQGroupBox( i18n("Album Description"), page_setupAlbumsList );
-    groupBox2->setColumnLayout(0, Qt::Vertical );
+    groupBox2->setColumnLayout(0, TQt::Vertical );
     groupBox2->layout()->setSpacing( 6 );
     groupBox2->layout()->setMargin( 11 );
     TQWhatsThis::add( groupBox2, i18n("<p>The description of the current Album in the selection list.") );
@@ -359,11 +359,11 @@ void AcquireImageDialog::setupAlbumsList(void)
             
     //---------------------------------------------
 
-    connect(m_addNewAlbumButton, TQT_SIGNAL(clicked()),
-            m_uploadPath, TQT_SLOT(mkdir()));
+    connect(m_addNewAlbumButton, TQ_SIGNAL(clicked()),
+            m_uploadPath, TQ_SLOT(mkdir()));
 
-    connect(m_uploadPath, TQT_SIGNAL( folderItemSelected( const KURL & ) ),
-            this, TQT_SLOT( slotAlbumSelected( const KURL & )));
+    connect(m_uploadPath, TQ_SIGNAL( folderItemSelected( const KURL & ) ),
+            this, TQ_SLOT( slotAlbumSelected( const KURL & )));
     
     //---------------------------------------------
                     
@@ -386,7 +386,7 @@ void AcquireImageDialog::slotAlbumSelected( const KURL &url )
     { 
        comments = (*albumIt).comment();
        category = (*albumIt).category();
-       date     = (*albumIt).date().toString( Qt::LocalDate );
+       date     = (*albumIt).date().toString( TQt::LocalDate );
        items.setNum((*albumIt).images().count());
     }
         
