@@ -84,7 +84,7 @@ void Plugin_BatchProcessImages::setup( TQWidget* widget )
                                         "borderimages",                      // Menu icon.
                                         0,                                   // default shortcut.
                                         this,
-                                        TQT_SLOT(slotActivate()),
+                                        TQ_SLOT(slotActivate()),
                                         actionCollection(),
                                         "batch_border_images");
 
@@ -92,7 +92,7 @@ void Plugin_BatchProcessImages::setup( TQWidget* widget )
                                         "colorimages",                       // Menu icon.
                                         0,                                   // default shortcut.
                                         this,
-                                        TQT_SLOT(slotActivate()),
+                                        TQ_SLOT(slotActivate()),
                                         actionCollection(),
                                         "batch_color_images");
 
@@ -100,7 +100,7 @@ void Plugin_BatchProcessImages::setup( TQWidget* widget )
                                         "convertimages",                     // Menu icon.
                                         0,                                   // default shortcut.
                                         this,
-                                        TQT_SLOT(slotActivate()),
+                                        TQ_SLOT(slotActivate()),
                                         actionCollection(),
                                         "batch_convert_images");
 
@@ -108,7 +108,7 @@ void Plugin_BatchProcessImages::setup( TQWidget* widget )
                                         "effectimages",                      // Menu icon.
                                         0,                                   // default shortcut.
                                         this,
-                                        TQT_SLOT(slotActivate()),
+                                        TQ_SLOT(slotActivate()),
                                         actionCollection(),
                                         "batch_effect_images");
 
@@ -116,7 +116,7 @@ void Plugin_BatchProcessImages::setup( TQWidget* widget )
                                         "filterimages",                      // Menu icon.
                                         0,                                   // default shortcut.
                                         this,
-                                        TQT_SLOT(slotActivate()),
+                                        TQ_SLOT(slotActivate()),
                                         actionCollection(),
                                         "batch_filter_images");
 
@@ -124,7 +124,7 @@ void Plugin_BatchProcessImages::setup( TQWidget* widget )
                                         "renameimages",                      // Menu icon.
                                         0,                                   // default shortcut.
                                         this,
-                                        TQT_SLOT(slotActivate()),
+                                        TQ_SLOT(slotActivate()),
                                         actionCollection(),
                                         "batch_rename_images");
 
@@ -132,7 +132,7 @@ void Plugin_BatchProcessImages::setup( TQWidget* widget )
                                         "recompressimages",                  // Menu icon.
                                         0,                                   // default shortcut.
                                         this,
-                                        TQT_SLOT(slotActivate()),
+                                        TQ_SLOT(slotActivate()),
                                         actionCollection(),
                                         "batch_recompress_images");
 
@@ -140,7 +140,7 @@ void Plugin_BatchProcessImages::setup( TQWidget* widget )
                                         "resizeimages",                      // Menu icon.
                                         0,                                   // default shortcut.
                                         this,
-                                        TQT_SLOT(slotActivate()),
+                                        TQ_SLOT(slotActivate()),
                                         actionCollection(),
                                         "batch_resize_images");
 
@@ -173,29 +173,29 @@ void Plugin_BatchProcessImages::setup( TQWidget* widget )
     m_action_recompressimages->setEnabled( enable );
     m_action_resizeimages->setEnabled( enable );
     
-    connect( interface, TQT_SIGNAL( currentAlbumChanged( bool ) ), 
-             m_action_borderimages, TQT_SLOT( setEnabled( bool ) ) );
+    connect( interface, TQ_SIGNAL( currentAlbumChanged( bool ) ), 
+             m_action_borderimages, TQ_SLOT( setEnabled( bool ) ) );
     
-    connect( interface, TQT_SIGNAL( currentAlbumChanged( bool ) ), 
-             m_action_colorimages, TQT_SLOT( setEnabled( bool ) ) );
+    connect( interface, TQ_SIGNAL( currentAlbumChanged( bool ) ), 
+             m_action_colorimages, TQ_SLOT( setEnabled( bool ) ) );
     
-    connect( interface, TQT_SIGNAL( currentAlbumChanged( bool ) ), 
-             m_action_convertimages, TQT_SLOT( setEnabled( bool ) ) );
+    connect( interface, TQ_SIGNAL( currentAlbumChanged( bool ) ), 
+             m_action_convertimages, TQ_SLOT( setEnabled( bool ) ) );
     
-    connect( interface, TQT_SIGNAL( currentAlbumChanged( bool ) ), 
-             m_action_effectimages, TQT_SLOT( setEnabled( bool ) ) );
+    connect( interface, TQ_SIGNAL( currentAlbumChanged( bool ) ), 
+             m_action_effectimages, TQ_SLOT( setEnabled( bool ) ) );
     
-    connect( interface, TQT_SIGNAL( currentAlbumChanged( bool ) ), 
-             m_action_filterimages, TQT_SLOT( setEnabled( bool ) ) );
+    connect( interface, TQ_SIGNAL( currentAlbumChanged( bool ) ), 
+             m_action_filterimages, TQ_SLOT( setEnabled( bool ) ) );
     
-    connect( interface, TQT_SIGNAL( currentAlbumChanged( bool ) ), 
-             m_action_renameimages, TQT_SLOT( setEnabled( bool ) ) );
+    connect( interface, TQ_SIGNAL( currentAlbumChanged( bool ) ), 
+             m_action_renameimages, TQ_SLOT( setEnabled( bool ) ) );
     
-    connect( interface, TQT_SIGNAL( currentAlbumChanged( bool ) ), 
-             m_action_recompressimages, TQT_SLOT( setEnabled( bool ) ) );
+    connect( interface, TQ_SIGNAL( currentAlbumChanged( bool ) ), 
+             m_action_recompressimages, TQ_SLOT( setEnabled( bool ) ) );
     
-    connect( interface, TQT_SIGNAL( currentAlbumChanged( bool ) ), 
-             m_action_resizeimages, TQT_SLOT( setEnabled( bool ) ) );
+    connect( interface, TQ_SIGNAL( currentAlbumChanged( bool ) ), 
+             m_action_resizeimages, TQ_SLOT( setEnabled( bool ) ) );
 }
 
 Plugin_BatchProcessImages::~Plugin_BatchProcessImages()
@@ -225,61 +225,61 @@ void Plugin_BatchProcessImages::slotActivate()
 
     if ( images.images().isEmpty() ) 
         {
-        KMessageBox::sorry(TQT_TQWIDGET(kapp->activeWindow()),
+        KMessageBox::sorry(kapp->activeWindow(),
                            i18n("Please select an album or a selection of images."));
         return;
         }
                                    
     KURL::List urlList = images.images();
 
-    TQString from(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name());
+    TQString from(sender()->name());
 
     if (from == "batch_convert_images")
         {
         m_ConvertImagesDialog = new KIPIBatchProcessImagesPlugin::ConvertImagesDialog( urlList,
-                                                                  interface, TQT_TQWIDGET(kapp->activeWindow()));
+                                                                  interface, kapp->activeWindow());
         m_ConvertImagesDialog->show();
         }
     else if (from == "batch_rename_images")
         {
         KIPIBatchProcessImagesPlugin::RenameImagesDialog
-            dlg(urlList, interface, TQT_TQWIDGET(kapp->activeWindow()));
+            dlg(urlList, interface, kapp->activeWindow());
         dlg.exec();
         }
     else if (from == "batch_border_images")
         {
         m_BorderImagesDialog = new KIPIBatchProcessImagesPlugin::BorderImagesDialog( urlList,
-                                                                 interface, TQT_TQWIDGET(kapp->activeWindow()));
+                                                                 interface, kapp->activeWindow());
         m_BorderImagesDialog->show();
         }
     else if (from == "batch_color_images")
         {
         m_ColorImagesDialog = new KIPIBatchProcessImagesPlugin::ColorImagesDialog( urlList, 
-                                                                interface, TQT_TQWIDGET(kapp->activeWindow()));
+                                                                interface, kapp->activeWindow());
         m_ColorImagesDialog->show();
         }
     else if (from == "batch_filter_images")
         {
         m_FilterImagesDialog = new KIPIBatchProcessImagesPlugin::FilterImagesDialog( urlList,
-                                                                 interface, TQT_TQWIDGET(kapp->activeWindow()));
+                                                                 interface, kapp->activeWindow());
         m_FilterImagesDialog->show();
         }
     else if (from == "batch_effect_images")
         {
         m_EffectImagesDialog = new KIPIBatchProcessImagesPlugin::EffectImagesDialog( urlList, 
-                                                                 interface, TQT_TQWIDGET(kapp->activeWindow()));
+                                                                 interface, kapp->activeWindow());
         m_EffectImagesDialog->show();
         }
     else if (from == "batch_recompress_images")
         {
         m_RecompressImagesDialog = new KIPIBatchProcessImagesPlugin::RecompressImagesDialog( urlList, 
-                                                                     interface, TQT_TQWIDGET(kapp->activeWindow()));
+                                                                     interface, kapp->activeWindow());
         m_RecompressImagesDialog->show();
         }
     else if (from == "batch_resize_images")
         {
         m_ResizeImagesDialog = new KIPIBatchProcessImagesPlugin::ResizeImagesDialog( urlList,
-                                                                 interface, TQT_TQWIDGET(kapp->activeWindow()));
+                                                                 interface, kapp->activeWindow());
         m_ResizeImagesDialog->show();
         }
     else
