@@ -797,7 +797,7 @@ void CDArchiving::createBody(TQTextStream& stream,
             ++urlIt)
     {
         TQFileInfo imInfo( (*urlIt).fileName());
-        TQString   imgName = makeFileNameUnique(fileNameList, webifyFileName(imInfo.baseName(TRUE)));
+        TQString   imgName = makeFileNameUnique(fileNameList, webifyFileName(imInfo.baseName(true)));
     }
     for ( KURL::List::iterator urlIt = images.begin() ;
             !m_cancelled && (urlIt != images.end());
@@ -1076,7 +1076,7 @@ bool CDArchiving::createPage(const TQString& imgGalleryDir,
     const TQDir pagesDir(imgGalleryDir + TQString::fromLatin1("/pages/"));
     const TQDir thumbsDir(imgGalleryDir + TQString::fromLatin1("/thumbs/"));
     const TQFileInfo fi (imgURL.fileName());
-    const TQString imgName = uniqueImgName + "." + fi.extension(FALSE);
+    const TQString imgName = uniqueImgName + "." + fi.extension(false);
     kdDebug( 51000 ) << "CreatePage: FileName: " << imgURL.fileName() << endl;
     kdDebug( 51000 ) << "CreatePage: uniqueFileName: " << imgName << endl;
     kdDebug( 51000 ) << "CreatePage: uniquePrevFileName: " << prevUniqueImgName << endl;
@@ -1706,11 +1706,11 @@ bool CDArchiving::addCollectionToK3bXMLProjectFile(const KIPI::ImageCollection&
         kdDebug( 51000 ) << "   Filename: " << (*it).fileName() << endl;
         TQFileInfo fInfo((*it).fileName());
         if (m_useHTMLInterface)
-            fName = makeFileNameUnique(fileNameList, webifyFileName(fInfo.baseName(TRUE)))
-                    + "." + fInfo.extension( FALSE );
+            fName = makeFileNameUnique(fileNameList, webifyFileName(fInfo.baseName(true)))
+                    + "." + fInfo.extension( false );
         else
-            fName = makeFileNameUnique(fileNameList, fInfo.baseName(TRUE))
-                    + "." + fInfo.extension( FALSE );
+            fName = makeFileNameUnique(fileNameList, fInfo.baseName(true))
+                    + "." + fInfo.extension( false );
         kdDebug( 51000 ) << "   Unique filename: " << fName  << endl;
         kdDebug( 51000 ) << "num of unique files: "<< fileNameList.size() << endl;
 
