@@ -62,7 +62,7 @@ void Plugin_CDArchiving::setup( TQWidget* widget )
                                         "cd",                             // Menu icon.
                                         0,
                                         this,
-                                        TQT_SLOT(slotActivate()),
+                                        TQ_SLOT(slotActivate()),
                                         actionCollection(),
                                         "cd_archiving");
 
@@ -123,10 +123,10 @@ void Plugin_CDArchiving::customEvent(TQCustomEvent *event)
 
     if (!m_progressDlg)
     {
-        m_progressDlg = new KIPI::BatchProgressDialog(TQT_TQWIDGET(kapp->activeWindow()), i18n("Archive to CD/DVD"));
+        m_progressDlg = new KIPI::BatchProgressDialog(kapp->activeWindow(), i18n("Archive to CD/DVD"));
 
-        connect(m_progressDlg, TQT_SIGNAL(cancelClicked()),
-                this, TQT_SLOT(slotCancel()));
+        connect(m_progressDlg, TQ_SIGNAL(cancelClicked()),
+                this, TQ_SLOT(slotCancel()));
 
         m_current = 0;
         m_progressDlg->show();
@@ -319,8 +319,8 @@ void Plugin_CDArchiving::customEvent(TQCustomEvent *event)
             m_progressDlg->setButtonCancelText( i18n("&Close") );
 #endif
 
-            disconnect(m_progressDlg, TQT_SIGNAL(cancelClicked()),
-                       this, TQT_SLOT(slotCancel()));
+            disconnect(m_progressDlg, TQ_SIGNAL(cancelClicked()),
+                       this, TQ_SLOT(slotCancel()));
 
             // Invoke K3b program.
 
