@@ -135,19 +135,19 @@ void FindDuplicateImages::readSettings(void)
 bool FindDuplicateImages::execDialog()
 {
     tqApp->setOverrideCursor( TQCursor(TQt::WaitCursor) );
-    m_findDuplicateDialog = new FindDuplicateDialog( m_interface, TQT_TQWIDGET(kapp->activeWindow()) );
+    m_findDuplicateDialog = new FindDuplicateDialog( m_interface, kapp->activeWindow() );
     tqApp->restoreOverrideCursor();
 
     readSettings();
 
-    connect( m_findDuplicateDialog, TQT_SIGNAL(updateCache(TQStringList)),
-             this, TQT_SLOT(slotUpdateCache(TQStringList)) );
+    connect( m_findDuplicateDialog, TQ_SIGNAL(updateCache(TQStringList)),
+             this, TQ_SLOT(slotUpdateCache(TQStringList)) );
 
-    connect( m_findDuplicateDialog, TQT_SIGNAL(clearCache(TQStringList)),
-             this, TQT_SLOT(slotClearCache(TQStringList)) );
+    connect( m_findDuplicateDialog, TQ_SIGNAL(clearCache(TQStringList)),
+             this, TQ_SLOT(slotClearCache(TQStringList)) );
 
-    connect( m_findDuplicateDialog, TQT_SIGNAL(clearAllCache()),
-             this, TQT_SLOT(slotClearAllCache()) );
+    connect( m_findDuplicateDialog, TQ_SIGNAL(clearAllCache()),
+             this, TQ_SLOT(slotClearAllCache()) );
 
     if ( m_findDuplicateDialog->exec() == TQDialog::Accepted )
     {
@@ -167,9 +167,9 @@ bool FindDuplicateImages::execDialog()
 void FindDuplicateImages::showResult()
 {
     if( !m_res.isEmpty() )
-        DisplayCompare((TQWidget *)(TQT_TQWIDGET(kapp->activeWindow())), m_interface, m_res).exec();
+        DisplayCompare((TQWidget *)(kapp->activeWindow()), m_interface, m_res).exec();
     else
-        KMessageBox::information(TQT_TQWIDGET(kapp->activeWindow()), i18n("No identical files found"));
+        KMessageBox::information(kapp->activeWindow(), i18n("No identical files found"));
 }
 
 
