@@ -111,9 +111,9 @@ GPSEditDialog::GPSEditDialog(TQWidget* parent, const GPSDataContainer& gpsData,
     TQPushButton *latResetButton = new TQPushButton(SmallIcon("clear_left"), TQString(), plainPage());
     TQPushButton *lonResetButton = new TQPushButton(SmallIcon("clear_left"), TQString(), plainPage());
 
-    d->altitudeInput->setValidator(new TQDoubleValidator(-20000.0, 20000.0, 1, TQT_TQOBJECT(this)));
-    d->latitudeInput->setValidator(new TQDoubleValidator(-90.0, 90.0, 12, TQT_TQOBJECT(this)));
-    d->longitudeInput->setValidator(new TQDoubleValidator(-180.0, 180.0, 12, TQT_TQOBJECT(this)));
+    d->altitudeInput->setValidator(new TQDoubleValidator(-20000.0, 20000.0, 1, this));
+    d->latitudeInput->setValidator(new TQDoubleValidator(-90.0, 90.0, 12, this));
+    d->longitudeInput->setValidator(new TQDoubleValidator(-180.0, 180.0, 12, this));
 
     d->goButton = new TQPushButton(i18n("Goto Location"), plainPage());
     d->goButton->setEnabled(false);
@@ -153,39 +153,39 @@ GPSEditDialog::GPSEditDialog(TQWidget* parent, const GPSDataContainer& gpsData,
     KHelpMenu* helpMenu = new KHelpMenu(this, d->about, false);
     helpMenu->menu()->removeItemAt(0);
     helpMenu->menu()->insertItem(i18n("Plugin Handbook"),
-                                 this, TQT_SLOT(slotHelp()), 0, -1, 0);
+                                 this, TQ_SLOT(slotHelp()), 0, -1, 0);
     actionButton(Help)->setPopup( helpMenu->menu() );
 
     // ---------------------------------------------------------------
 
-    connect(altResetButton, TQT_SIGNAL(released()),
-            d->altitudeInput, TQT_SLOT(clear()));
+    connect(altResetButton, TQ_SIGNAL(released()),
+            d->altitudeInput, TQ_SLOT(clear()));
 
-    connect(latResetButton, TQT_SIGNAL(released()),
-            d->latitudeInput, TQT_SLOT(clear()));
+    connect(latResetButton, TQ_SIGNAL(released()),
+            d->latitudeInput, TQ_SLOT(clear()));
 
-    connect(lonResetButton, TQT_SIGNAL(released()),
-            d->longitudeInput, TQT_SLOT(clear()));
+    connect(lonResetButton, TQ_SIGNAL(released()),
+            d->longitudeInput, TQ_SLOT(clear()));
 
-    connect(d->altitudeInput, TQT_SIGNAL(textChanged(const TQString&)),
-            this, TQT_SLOT(slotGPSPositionChanged()));
+    connect(d->altitudeInput, TQ_SIGNAL(textChanged(const TQString&)),
+            this, TQ_SLOT(slotGPSPositionChanged()));
 
-    connect(d->latitudeInput, TQT_SIGNAL(textChanged(const TQString&)),
-            this, TQT_SLOT(slotGPSPositionChanged()));
+    connect(d->latitudeInput, TQ_SIGNAL(textChanged(const TQString&)),
+            this, TQ_SLOT(slotGPSPositionChanged()));
 
-    connect(d->longitudeInput, TQT_SIGNAL(textChanged(const TQString&)),
-            this, TQT_SLOT(slotGPSPositionChanged()));
+    connect(d->longitudeInput, TQ_SIGNAL(textChanged(const TQString&)),
+            this, TQ_SLOT(slotGPSPositionChanged()));
 
-    connect(d->worldMap, TQT_SIGNAL(signalNewGPSLocationFromMap(const TQString&, const TQString&, const TQString&)),
-            this, TQT_SLOT(slotNewGPSLocationFromMap(const TQString&, const TQString&, const TQString&)));
+    connect(d->worldMap, TQ_SIGNAL(signalNewGPSLocationFromMap(const TQString&, const TQString&, const TQString&)),
+            this, TQ_SLOT(slotNewGPSLocationFromMap(const TQString&, const TQString&, const TQString&)));
 
-    connect(d->goButton, TQT_SIGNAL(released()),
-            this, TQT_SLOT(slotGotoLocation()));
+    connect(d->goButton, TQ_SIGNAL(released()),
+            this, TQ_SLOT(slotGotoLocation()));
 
     // ---------------------------------------------------------------
 
     readSettings();
-    TQTimer::singleShot(0, this, TQT_SLOT(slotUpdateWorldMap()));
+    TQTimer::singleShot(0, this, TQ_SLOT(slotUpdateWorldMap()));
 }
 
 GPSEditDialog::~GPSEditDialog()
