@@ -203,45 +203,45 @@ EXIFLight::EXIFLight(TQWidget* parent)
 
     // --------------------------------------------------------
 
-    connect(d->lightSourceCheck, TQT_SIGNAL(toggled(bool)),
-            d->lightSourceCB, TQT_SLOT(setEnabled(bool)));
+    connect(d->lightSourceCheck, TQ_SIGNAL(toggled(bool)),
+            d->lightSourceCB, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->flashModeCheck, TQT_SIGNAL(toggled(bool)),
-            d->flashModeCB, TQT_SLOT(setEnabled(bool)));
+    connect(d->flashModeCheck, TQ_SIGNAL(toggled(bool)),
+            d->flashModeCB, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->flashEnergyCheck, TQT_SIGNAL(toggled(bool)),
-            d->flashEnergyEdit, TQT_SLOT(setEnabled(bool)));
+    connect(d->flashEnergyCheck, TQ_SIGNAL(toggled(bool)),
+            d->flashEnergyEdit, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->whiteBalanceCheck, TQT_SIGNAL(toggled(bool)),
-            d->whiteBalanceCB, TQT_SLOT(setEnabled(bool)));
+    connect(d->whiteBalanceCheck, TQ_SIGNAL(toggled(bool)),
+            d->whiteBalanceCB, TQ_SLOT(setEnabled(bool)));
 
     // --------------------------------------------------------
 
-    connect(d->flashEnergyCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->flashEnergyCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->lightSourceCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->lightSourceCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->flashModeCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->flashModeCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->whiteBalanceCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->whiteBalanceCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
     // --------------------------------------------------------
 
-    connect(d->lightSourceCB, TQT_SIGNAL(activated(int)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->lightSourceCB, TQ_SIGNAL(activated(int)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->flashModeCB, TQT_SIGNAL(activated(int)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->flashModeCB, TQ_SIGNAL(activated(int)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->whiteBalanceCB, TQT_SIGNAL(activated(int)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->whiteBalanceCB, TQ_SIGNAL(activated(int)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->flashEnergyEdit, TQT_SIGNAL(valueChanged(double)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->flashEnergyEdit, TQ_SIGNAL(valueChanged(double)),
+            this, TQ_SIGNAL(signalModified()));
 }
 
 EXIFLight::~EXIFLight()
