@@ -97,7 +97,7 @@ IPTCStatus::IPTCStatus(TQWidget* parent)
 
     // IPTC only accept printable Ascii char.
     TQRegExp asciiRx("[\x20-\x7F]+$");
-    TQValidator *asciiValidator = new TQRegExpValidator(asciiRx, TQT_TQOBJECT(this));
+    TQValidator *asciiValidator = new TQRegExpValidator(asciiRx, this);
 
     // --------------------------------------------------------
 
@@ -217,81 +217,81 @@ IPTCStatus::IPTCStatus(TQWidget* parent)
 
     // --------------------------------------------------------
 
-    connect(d->priorityCheck, TQT_SIGNAL(toggled(bool)),
-            d->priorityCB, TQT_SLOT(setEnabled(bool)));
+    connect(d->priorityCheck, TQ_SIGNAL(toggled(bool)),
+            d->priorityCB, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->objectCycleCheck, TQT_SIGNAL(toggled(bool)),
-            d->objectCycleCB, TQT_SLOT(setEnabled(bool)));
+    connect(d->objectCycleCheck, TQ_SIGNAL(toggled(bool)),
+            d->objectCycleCB, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->objectTypeCheck, TQT_SIGNAL(toggled(bool)),
-            d->objectTypeCB, TQT_SLOT(setEnabled(bool)));
+    connect(d->objectTypeCheck, TQ_SIGNAL(toggled(bool)),
+            d->objectTypeCB, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->objectTypeCheck, TQT_SIGNAL(toggled(bool)),
-            d->objectTypeDescEdit, TQT_SLOT(setEnabled(bool)));
+    connect(d->objectTypeCheck, TQ_SIGNAL(toggled(bool)),
+            d->objectTypeDescEdit, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->objectAttributeCheck, TQT_SIGNAL(toggled(bool)),
-            d->objectAttributeCB, TQT_SLOT(setEnabled(bool)));
+    connect(d->objectAttributeCheck, TQ_SIGNAL(toggled(bool)),
+            d->objectAttributeCB, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->objectAttributeCheck, TQT_SIGNAL(toggled(bool)),
-            d->objectAttributeDescEdit, TQT_SLOT(setEnabled(bool)));
+    connect(d->objectAttributeCheck, TQ_SIGNAL(toggled(bool)),
+            d->objectAttributeDescEdit, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->statusCheck, TQT_SIGNAL(toggled(bool)),
-            d->statusEdit, TQT_SLOT(setEnabled(bool)));
+    connect(d->statusCheck, TQ_SIGNAL(toggled(bool)),
+            d->statusEdit, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->JobIDCheck, TQT_SIGNAL(toggled(bool)),
-            d->JobIDEdit, TQT_SLOT(setEnabled(bool)));
+    connect(d->JobIDCheck, TQ_SIGNAL(toggled(bool)),
+            d->JobIDEdit, TQ_SLOT(setEnabled(bool)));
 
     // --------------------------------------------------------
 
-    connect(d->priorityCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->priorityCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->objectCycleCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->objectCycleCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->objectTypeCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->objectTypeCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->objectTypeCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->objectTypeCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->objectAttributeCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->objectAttributeCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->objectAttributeCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->objectAttributeCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->statusCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->statusCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->JobIDCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->JobIDCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
     // --------------------------------------------------------
 
-    connect(d->priorityCB, TQT_SIGNAL(activated(int)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->priorityCB, TQ_SIGNAL(activated(int)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->objectCycleCB, TQT_SIGNAL(activated(int)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->objectCycleCB, TQ_SIGNAL(activated(int)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->objectTypeCB, TQT_SIGNAL(activated(int)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->objectTypeCB, TQ_SIGNAL(activated(int)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->objectAttributeCB, TQT_SIGNAL(activated(int)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->objectAttributeCB, TQ_SIGNAL(activated(int)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->statusEdit, TQT_SIGNAL(textChanged(const TQString &)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->statusEdit, TQ_SIGNAL(textChanged(const TQString &)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->objectTypeDescEdit, TQT_SIGNAL(textChanged(const TQString &)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->objectTypeDescEdit, TQ_SIGNAL(textChanged(const TQString &)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->objectAttributeDescEdit, TQT_SIGNAL(textChanged(const TQString &)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->objectAttributeDescEdit, TQ_SIGNAL(textChanged(const TQString &)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->JobIDEdit, TQT_SIGNAL(textChanged(const TQString &)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->JobIDEdit, TQ_SIGNAL(textChanged(const TQString &)),
+            this, TQ_SIGNAL(signalModified()));
 }
 
 IPTCStatus::~IPTCStatus()
