@@ -35,7 +35,7 @@ class IPTCSubjectsPriv;
 
 class IPTCSubjects : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     
 public:
