@@ -31,7 +31,7 @@ class TDEActionMenu;
 
 class Plugin_MetadataEdit : public KIPI::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
