@@ -173,7 +173,7 @@ SendImagesDialog::SendImagesDialog(TQWidget *parent, KIPI::Interface* interface,
     m_helpButton        = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQT_SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQ_SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 
     slotMailAgentChanged(m_mailAgentName->currentItem());
@@ -266,7 +266,7 @@ void SendImagesDialog::setupImagesList(void)
                                                  "button or use the drag-and-drop."));
     grid->addMultiCellWidget(m_ImagesFilesListBox, 0, 2, 0, 1);
 
-    KButtonBox* imagesListButtonBox = new KButtonBox( m_groupBoxImageList,Qt::Vertical );
+    KButtonBox* imagesListButtonBox = new KButtonBox( m_groupBoxImageList,TQt::Vertical );
     TQPushButton* m_addImagesButton  = imagesListButtonBox->addButton ( i18n( "&Add ..." ) );
     TQWhatsThis::add( m_addImagesButton, i18n("<p>Add images to the list.") );
     TQPushButton* m_remImagesButton  = imagesListButtonBox->addButton ( i18n( "&Remove" ));
@@ -286,7 +286,7 @@ void SendImagesDialog::setupImagesList(void)
     //---------------------------------------------
 
     TQGroupBox * groupBox2 = new TQGroupBox( i18n("Image Description"), page_setupImagesList );
-    groupBox2->setColumnLayout(0, Qt::Vertical );
+    groupBox2->setColumnLayout(0, TQt::Vertical );
     groupBox2->layout()->setSpacing( 6 );
     groupBox2->layout()->setMargin( 11 );
     TQWhatsThis::add( groupBox2, i18n("<p>The description of the currently selected image on the list.") );
@@ -307,17 +307,17 @@ void SendImagesDialog::setupImagesList(void)
 
     //---------------------------------------------
 
-    connect(m_addImagesButton, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotImagesFilesButtonAdd()));
+    connect(m_addImagesButton, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotImagesFilesButtonAdd()));
 
-    connect(m_remImagesButton, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotImagesFilesButtonRem()));
+    connect(m_remImagesButton, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotImagesFilesButtonRem()));
 
-    connect(m_ImagesFilesListBox, TQT_SIGNAL( currentChanged( TQListBoxItem * ) ),
-            this, TQT_SLOT( slotImageSelected( TQListBoxItem * )));
+    connect(m_ImagesFilesListBox, TQ_SIGNAL( currentChanged( TQListBoxItem * ) ),
+            this, TQ_SLOT( slotImageSelected( TQListBoxItem * )));
 
-    connect(m_ImagesFilesListBox, TQT_SIGNAL( addedDropItems(TQStringList) ),
-            this, TQT_SLOT( slotAddDropItems(TQStringList)));
+    connect(m_ImagesFilesListBox, TQ_SIGNAL( addedDropItems(TQStringList) ),
+            this, TQ_SLOT( slotAddDropItems(TQStringList)));
 }
 
 void SendImagesDialog::setImagesList( const KURL::List& Files )
@@ -404,8 +404,8 @@ void SendImagesDialog::setupEmailOptions(void)
     hlay10->addStretch( 1 );
     hlay10->addWidget( m_mailAgentName );
 
-    connect(m_mailAgentName, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotMailAgentChanged(int)));
+    connect(m_mailAgentName, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotMailAgentChanged(int)));
 
     //---------------------------------------------
 
@@ -416,8 +416,8 @@ void SendImagesDialog::setupEmailOptions(void)
     m_labelThunderbirdBinPath->setBuddy( m_ThunderbirdBinPath );
     vlay->addWidget(m_ThunderbirdBinPath);
 
-    connect(m_ThunderbirdBinPath, TQT_SIGNAL(textChanged(const TQString&)),
-            this, TQT_SLOT(slotThunderbirdBinPathChanged(const TQString&)));
+    connect(m_ThunderbirdBinPath, TQ_SIGNAL(textChanged(const TQString&)),
+            this, TQ_SLOT(slotThunderbirdBinPathChanged(const TQString&)));
 
     TQWhatsThis::add( m_ThunderbirdBinPath, i18n("<p>The path name to the Thunderbird binary program.") );
 
@@ -433,7 +433,7 @@ void SendImagesDialog::setupEmailOptions(void)
     //---------------------------------------------
 
     TQGroupBox * groupBox2 = new TQGroupBox( i18n("Image Properties"), page_setupEmailOptions );
-    groupBox2->setColumnLayout(0, Qt::Vertical );
+    groupBox2->setColumnLayout(0, TQt::Vertical );
     groupBox2->layout()->setSpacing( 6 );
     groupBox2->layout()->setMargin( 11 );
     TQWhatsThis::add( groupBox2, i18n("<p>The properties of images to send.") );
@@ -535,20 +535,20 @@ void SendImagesDialog::setupEmailOptions(void)
 		    
     //---------------------------------------------
 
-    connect(m_changeImagesProp, TQT_SIGNAL(toggled(bool)),
-            m_labelImageSize, TQT_SLOT(setEnabled(bool)));
+    connect(m_changeImagesProp, TQ_SIGNAL(toggled(bool)),
+            m_labelImageSize, TQ_SLOT(setEnabled(bool)));
 
-    connect(m_changeImagesProp, TQT_SIGNAL(toggled(bool)),
-            m_imagesResize, TQT_SLOT(setEnabled(bool)));
+    connect(m_changeImagesProp, TQ_SIGNAL(toggled(bool)),
+            m_imagesResize, TQ_SLOT(setEnabled(bool)));
 
-    connect(m_changeImagesProp, TQT_SIGNAL(toggled(bool)),
-            m_imageCompression, TQT_SLOT(setEnabled(bool)));
+    connect(m_changeImagesProp, TQ_SIGNAL(toggled(bool)),
+            m_imageCompression, TQ_SLOT(setEnabled(bool)));
 
-    connect(m_changeImagesProp, TQT_SIGNAL(toggled(bool)),
-            m_labelImageFormat, TQT_SLOT(setEnabled(bool)));
+    connect(m_changeImagesProp, TQ_SIGNAL(toggled(bool)),
+            m_labelImageFormat, TQ_SLOT(setEnabled(bool)));
 
-    connect(m_changeImagesProp, TQT_SIGNAL(toggled(bool)),
-            m_imagesFormat, TQT_SLOT(setEnabled(bool)));
+    connect(m_changeImagesProp, TQ_SIGNAL(toggled(bool)),
+            m_imagesFormat, TQ_SLOT(setEnabled(bool)));
 }
 
 void SendImagesDialog::slotHelp()
@@ -629,11 +629,11 @@ void SendImagesDialog::slotImageSelected( TQListBoxItem * item )
 
     m_thumbJob = TDEIO::filePreview( pitem->url(), m_imageLabel->height() );
 
-    connect(m_thumbJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
-            TQT_SLOT(slotGotPreview(const KFileItem*, const TQPixmap&)));
+    connect(m_thumbJob, TQ_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
+            TQ_SLOT(slotGotPreview(const KFileItem*, const TQPixmap&)));
 
-    connect(m_thumbJob, TQT_SIGNAL(failed(const KFileItem*)),
-            TQT_SLOT(slotFailedPreview(const KFileItem*)));
+    connect(m_thumbJob, TQ_SIGNAL(failed(const KFileItem*)),
+            TQ_SLOT(slotFailedPreview(const KFileItem*)));
 }
 
 void SendImagesDialog::slotGotPreview(const KFileItem*, const TQPixmap &pixmap)
