@@ -77,7 +77,7 @@ void Plugin_Sync::setup(TQWidget* widget)
   mpActionSync = new TDEAction(i18n("Synchronize..."),
     0,
     this,
-    TQT_SLOT(slotSync()),
+    TQ_SLOT(slotSync()),
     actionCollection(),
     "sync");
   mpActionSync->setEnabled(true);
@@ -86,7 +86,7 @@ void Plugin_Sync::setup(TQWidget* widget)
   mpActionConfigure = new TDEAction(i18n("Configure Synchronization..."),
     0,
     this,
-    TQT_SLOT(slotConfigure()),
+    TQ_SLOT(slotConfigure()),
     actionCollection(),
     "sync");
   mpActionConfigure->setEnabled(true);
@@ -95,7 +95,7 @@ void Plugin_Sync::setup(TQWidget* widget)
   mpActionSettingsCollection = new TDEAction(i18n("Synchronization Settings..."),
     0,
     this,
-    TQT_SLOT(slotSettingsCollection()),
+    TQ_SLOT(slotSettingsCollection()),
     actionCollection(),
     "sync");
   mpActionSettingsCollection->setEnabled(true);
@@ -104,7 +104,7 @@ void Plugin_Sync::setup(TQWidget* widget)
   mpActionSettingsImage = new TDEAction(i18n("Synchronization Settings..."),
     0,
     this,
-    TQT_SLOT(slotSettingsImage()),
+    TQ_SLOT(slotSettingsImage()),
     actionCollection(),
     "sync");
   mpActionSettingsImage->setEnabled(true);
