@@ -45,7 +45,7 @@ class TimeAdjustDialogPrivate;
 
 class TimeAdjustDialog :public KDialogBase 
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
